import { ElementType, ForwardRefExoticComponent, HTMLAttributes, RefAttributes } from 'react';
import { FontFamily, FontSize, FontWeight, LetterSpacing, LineHeight, Shadow, SxColor } from '../../tokens';
import type { ValueOrArray } from '../../types';
export declare type TextProps = {
    /** Element type to render. Defaults to `div`. */
    as?: ElementType;
    /** Color of the text. Inherited by default. */
    color?: ValueOrArray<SxColor | null>;
    /** Font family. Inherited by default. */
    font?: ValueOrArray<keyof typeof FontFamily | null>;
    /** Font weight. Inherited by default. */
    weight?: ValueOrArray<keyof typeof FontWeight | null>;
    /** Whether the text should be italic. Inherited by default. */
    italic?: ValueOrArray<boolean | null>;
    /** Font size. Inherited by default. */
    size?: ValueOrArray<keyof typeof FontSize | null>;
    /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
    lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
    /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
    letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
    /** Text alignment. Inherited by default. */
    align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
    /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
    hyphens?: ValueOrArray<boolean | null>;
    /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
    truncate?: boolean;
    /** Whether to render the text in UPPERCASE. Inherited by default. */
    uppercase?: boolean;
    /** Text shadow. Inherited by default. */
    shadow?: ValueOrArray<keyof typeof Shadow | null>;
} & Omit<HTMLAttributes<HTMLElement>, 'color'>;
/**
 * Base `Text` component.
 *
 * Renders a `div` by default, but can be changed with the `as` prop (e.g. `as="span"` to make it inline).
 *
 * Variants are available as properties on the component, e.g. `Text.H96` renders a 96px heading (`h2` tag),
 * `Text.P16` renders a 16px paragraph (`p` tag), `Text.C10` renders a 10px uppercase caption (`div`),
 * and `Text.M12` renders 12px monospace text (`div`).
 */
export declare const Text: ForwardRefExoticComponent<{
    /** Element type to render. Defaults to `div`. */
    as?: ElementType;
    /** Color of the text. Inherited by default. */
    color?: ValueOrArray<SxColor | null>;
    /** Font family. Inherited by default. */
    font?: ValueOrArray<keyof typeof FontFamily | null>;
    /** Font weight. Inherited by default. */
    weight?: ValueOrArray<keyof typeof FontWeight | null>;
    /** Whether the text should be italic. Inherited by default. */
    italic?: ValueOrArray<boolean | null>;
    /** Font size. Inherited by default. */
    size?: ValueOrArray<keyof typeof FontSize | null>;
    /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
    lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
    /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
    letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
    /** Text alignment. Inherited by default. */
    align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
    /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
    hyphens?: ValueOrArray<boolean | null>;
    /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
    truncate?: boolean;
    /** Whether to render the text in UPPERCASE. Inherited by default. */
    uppercase?: boolean;
    /** Text shadow. Inherited by default. */
    shadow?: ValueOrArray<keyof typeof Shadow | null>;
} & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>> & {
    /** Heading with a font size of 96px on desktop, 64px on mobile. */
    H96: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 64px on desktop, 48px on mobile. */
    H64: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 48px on desktop, 40px on mobile. */
    H48: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 40px on desktop, 32px on mobile. */
    H40: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 32px on desktop, 24px on mobile. */
    H32: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 24px on desktop, 20px on mobile. */
    H24: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 20px. */
    H20: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 18px. */
    H18: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 16px. */
    H16: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 14px. */
    H14: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Heading with a font size of 12px. */
    H12: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 32px on desktop, 24px on mobile. */
    P32: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 24px on desktop, 20px on mobile. */
    P24: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 20px on desktop, 18px on mobile. */
    P20: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 18px on desktop, 16px on mobile. */
    P18: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 16px on desktop, 14px on mobile. */
    P16: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 14px on desktop, 12px on mobile. */
    P14: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Paragraph with a font size of 12px. */
    P12: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Uppercase caption with a font size of 14px. */
    C14: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Uppercase caption with a font size of 12px. */
    C12: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Uppercase caption with a font size of 10px. */
    C10: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Serif italic text as blockquote with font size of 32px */
    Q32: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Serif italic text as blockquote with font size of 24px */
    Q24: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Serif italic text as blockquote with font size of 20px */
    Q20: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Monospace text with a font size of 16px. */
    M16: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Monospace text with a font size of 14px. */
    M14: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
    /** Monospace text with a font size of 12px. */
    M12: ForwardRefExoticComponent<{
        /** Element type to render. Defaults to `div`. */
        as?: ElementType;
        /** Color of the text. Inherited by default. */
        color?: ValueOrArray<SxColor | null>;
        /** Font family. Inherited by default. */
        font?: ValueOrArray<keyof typeof FontFamily | null>;
        /** Font weight. Inherited by default. */
        weight?: ValueOrArray<keyof typeof FontWeight | null>;
        /** Whether the text should be italic. Inherited by default. */
        italic?: ValueOrArray<boolean | null>;
        /** Font size. Inherited by default. */
        size?: ValueOrArray<keyof typeof FontSize | null>;
        /** Line height or leading. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        lineHeight?: ValueOrArray<keyof typeof LineHeight | null>;
        /** Letter spacing or tracking. Inherited by default, unless `size` is set, in which case it defaults to a value that is appropriate for the given `size`. */
        letterSpacing?: ValueOrArray<keyof typeof LetterSpacing | null>;
        /** Text alignment. Inherited by default. */
        align?: ValueOrArray<'left' | 'center' | 'right' | 'justify' | null>;
        /** Whether to hyphenate the text when it wraps across multiple lines. Inherited by default. */
        hyphens?: ValueOrArray<boolean | null>;
        /** Whether to force the text to be on a single line, truncating it with an ellipsis (…) if needed. Defaults to `false`. */
        truncate?: boolean;
        /** Whether to render the text in UPPERCASE. Inherited by default. */
        uppercase?: boolean;
        /** Text shadow. Inherited by default. */
        shadow?: ValueOrArray<keyof typeof Shadow | null>;
    } & Omit<HTMLAttributes<HTMLElement>, "color"> & RefAttributes<HTMLElement>>;
};
